/*******************************************************************************
 * Copyright (c) 2006 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 * IBM Corporation - initial API and implementation
 * yyyymmdd bug      Email and other contact information
 * -------- -------- -----------------------------------------------------------
 * 20061128          pmoogk@ca.ibm.com - Peter Moogk, Initial coding
 *******************************************************************************/

package org.eclipse.example.webservice.runtime.ui;

import org.eclipse.wst.command.internal.env.core.data.DataMappingRegistry;
import org.eclipse.wst.command.internal.env.ui.widgets.INamedWidgetContributor;
import org.eclipse.wst.command.internal.env.ui.widgets.INamedWidgetContributorFactory;
import org.eclipse.wst.command.internal.env.ui.widgets.SimpleWidgetContributor;
import org.eclipse.wst.command.internal.env.ui.widgets.WidgetBindingToWidgetFactoryAdapter;
import org.eclipse.wst.command.internal.env.ui.widgets.WidgetContributor;
import org.eclipse.wst.command.internal.env.ui.widgets.WidgetContributorFactory;
import org.eclipse.wst.command.internal.env.ui.widgets.WidgetDataContributor;

public class SkelConfigWidgetFactory implements INamedWidgetContributorFactory {

	private SimpleWidgetContributor  config1WidgetContrib;
  private SimpleWidgetContributor  optional1WidgetContrib;
	private SimpleWidgetContributor  optional2WidgetContrib;
  private DataModel                model;
	
	public SkelConfigWidgetFactory()
	{	  
	}
	
	public INamedWidgetContributor getFirstNamedWidget() 
	{
    if( config1WidgetContrib == null ) init();
    
	  return config1WidgetContrib;
	}

	public INamedWidgetContributor getNextNamedWidget( INamedWidgetContributor widgetContributor) 
	{
    if( config1WidgetContrib == null ) init();
    
    INamedWidgetContributor nextWidgetContrib = null;
    
    if( widgetContributor == config1WidgetContrib && model.isOptionalPage1() )
    {
      nextWidgetContrib = optional1WidgetContrib;
    }
    else if( (widgetContributor == optional1WidgetContrib ||
              widgetContributor == config1WidgetContrib ) && 
              model.isOptionalPage2() )
    {
      nextWidgetContrib = optional2WidgetContrib;
    }
    
	  return nextWidgetContrib;
	}
	
	public void registerDataMappings(DataMappingRegistry dataRegistry) 
	{
    // Map the data model from the defaulting command to this widget factory.
    // The framework will actually to the call to getWebServiceDataModel in
    // the ExampleDefaultingCommand class and then call the setWebServiceDataModel
    // method in this class.
    dataRegistry.addMapping( ExampleDefaultingCommand.class, "WebServiceDataModel", SkelConfigWidgetFactory.class );
	}
  
  public void setWebServiceDataModel( DataModel model )
  {
    this.model = model;
  }
  
  private void init()
  {
    SkelConfigWidget  skel1 = new SkelConfigWidget( model );
    Skel2ConfigWidget skel2 = new Skel2ConfigWidget( model );
    Skel3ConfigWidget skel3 = new Skel3ConfigWidget( model );
    
    // The strings below have not been put into a properties file to make this
    // example code more readable.  Web services extenders should put all user
    // readable strings into a properties file for translation.
    config1WidgetContrib  = createWidgetContributor( "Example TD Config page 1 title",
                                                     "Some text describing this example TD config page", 
                                                     skel1 );
    
    optional1WidgetContrib  = createWidgetContributor( "Example TD optional page 2 title",
                                                       "Some text describing this example TD optional page 1", 
                                                       skel2 );
    
    optional2WidgetContrib  = createWidgetContributor( "Example TD optional page 3 title",
                                                       "Some text describing this example TD optional page 2", 
                                                       skel3 );
  }
  
  private SimpleWidgetContributor createWidgetContributor( String title, String description, final WidgetDataContributor contributor )
  {
    SimpleWidgetContributor widgetContrib  = new SimpleWidgetContributor();
    widgetContrib.setTitle(title);
    widgetContrib.setDescription(description);
    widgetContrib.setFactory( new WidgetContributorFactory()
                              {
                                public WidgetContributor create()
                                {
                                  return contributor;
                                }
                              });
    
    return widgetContrib;
  }   
}
